/// <reference types="codemirror" />
import { AbbreviationContext, Options } from 'emmet';
export interface ActivationContext extends SyntaxContext {
    options: Partial<Options>;
}
interface HTMLContextOptions {
    xml?: boolean;
    skipCSS?: boolean;
}
interface SyntaxContext {
    syntax: string;
    context?: AbbreviationContext;
    inline?: boolean;
}
/**
 * Returns valid abbreviation context for given location in editor which can be
 * used for abbreviation expanding.
 * For example, in given HTML code:
 * `<div title="Sample" style="">Hello world</div>`
 * it’s not allowed to expand abbreviations inside `<div ...>` or `</div>`,
 * yet it’s allowed inside `style` attribute and between tags.
 *
 * This method ensures that given `pos` is inside location allowed for expanding
 * abbreviations and returns context data about it
 */
export default function getAbbreviationContext(editor: CodeMirror.Editor, pos: number): ActivationContext | undefined;
/**
 * Returns HTML autocomplete activation context for given location in source code,
 * if available
 */
export declare function getHTMLContext(code: string, pos: number, opt?: HTMLContextOptions): SyntaxContext | undefined;
export declare function getCSSContext(code: string, pos: number): SyntaxContext | undefined;
export {};
